@@ -1,7 +1,7 @@
+import hyppo.discrim
 import hyppo.independence
 import hyppo.ksample
 import hyppo.time_series
-import hyppo.sims
-import hyppo.discrim
+import hyppo.tools
 
-__version__ = "0.1.3"
+__version__ = "0.2.0"
